@@ -4,10 +4,11 @@ from collections import namedtuple
 from operator import attrgetter
 
 import attr
-from six.moves import map
 
+from ..deprecated import MARK_PARAMETERSET_UNPACKING, MARK_INFO_ATTRIBUTE
 from ..compat import NOTSET, getfslineno, MappingMixin
-from ..deprecated import MARK_PARAMETERSET_UNPACKING
+from six.moves import map, reduce
+
 
 EMPTY_PARAMETERSET_OPTION = "empty_parameter_set_mark"
 
@@ -19,32 +20,35 @@ def alias(name, warning=None):
         warnings.warn(warning, stacklevel=2)
         return getter(self)
 
-    return property(getter if warning is None else warned, doc='alias for ' + name)
+    return property(getter if warning is None else warned, doc="alias for " + name)
 
 
 def istestfunc(func):
-    return hasattr(func, "__call__") and \
-        getattr(func, "__name__", "<lambda>") != "<lambda>"
+    return hasattr(func, "__call__") and getattr(
+        func, "__name__", "<lambda>"
+    ) != "<lambda>"
 
 
 def get_empty_parameterset_mark(config, argnames, func):
     requested_mark = config.getini(EMPTY_PARAMETERSET_OPTION)
-    if requested_mark in ('', None, 'skip'):
+    if requested_mark in ("", None, "skip"):
         mark = MARK_GEN.skip
-    elif requested_mark == 'xfail':
+    elif requested_mark == "xfail":
         mark = MARK_GEN.xfail(run=False)
     else:
         raise LookupError(requested_mark)
     fs, lineno = getfslineno(func)
     reason = "got empty parameter set %r, function %s at %s:%d" % (
-        argnames, func.__name__, fs, lineno)
+        argnames, func.__name__, fs, lineno
+    )
     return mark(reason=reason)
 
 
-class ParameterSet(namedtuple('ParameterSet', 'values, marks, id')):
+class ParameterSet(namedtuple("ParameterSet", "values, marks, id")):
+
     @classmethod
     def param(cls, *values, **kw):
-        marks = kw.pop('marks', ())
+        marks = kw.pop("marks", ())
         if isinstance(marks, MarkDecorator):
             marks = marks,
         else:
@@ -77,8 +81,9 @@ class ParameterSet(namedtuple('ParameterSet', 'values, marks, id')):
         newmarks = []
         argval = parameterset
         while isinstance(argval, MarkDecorator):
-            newmarks.append(MarkDecorator(Mark(
-                argval.markname, argval.args[:-1], argval.kwargs)))
+            newmarks.append(
+                MarkDecorator(Mark(argval.markname, argval.args[:-1], argval.kwargs))
+            )
             argval = argval.args[-1]
         assert not isinstance(argval, ParameterSet)
         if legacy_force_tuple:
@@ -98,30 +103,39 @@ class ParameterSet(namedtuple('ParameterSet', 'values, marks, id')):
             force_tuple = False
         parameters = [
             ParameterSet.extract_from(x, legacy_force_tuple=force_tuple)
-            for x in argvalues]
+            for x in argvalues
+        ]
         del argvalues
 
         if not parameters:
             mark = get_empty_parameterset_mark(config, argnames, func)
-            parameters.append(ParameterSet(
-                values=(NOTSET,) * len(argnames),
-                marks=[mark],
-                id=None,
-            ))
+            parameters.append(
+                ParameterSet(values=(NOTSET,) * len(argnames), marks=[mark], id=None)
+            )
         return argnames, parameters
 
 
 @attr.s(frozen=True)
 class Mark(object):
-    name = attr.ib()
-    args = attr.ib()
-    kwargs = attr.ib()
+    #: name of the mark
+    name = attr.ib(type=str)
+    #: positional arguments of the mark decorator
+    args = attr.ib(type="List[object]")
+    #: keyword arguments of the mark decorator
+    kwargs = attr.ib(type="Dict[str, object]")
 
     def combined_with(self, other):
+        """
+        :param other: the mark to combine with
+        :type other: Mark
+        :rtype: Mark
+
+        combines by appending aargs and merging the mappings
+        """
         assert self.name == other.name
         return Mark(
-            self.name, self.args + other.args,
-            dict(self.kwargs, **other.kwargs))
+            self.name, self.args + other.args, dict(self.kwargs, **other.kwargs)
+        )
 
 
 @attr.s
@@ -161,9 +175,9 @@ class MarkDecorator(object):
 
     mark = attr.ib(validator=attr.validators.instance_of(Mark))
 
-    name = alias('mark.name')
-    args = alias('mark.args')
-    kwargs = alias('mark.kwargs')
+    name = alias("mark.name")
+    args = alias("mark.args")
+    kwargs = alias("mark.kwargs")
 
     @property
     def markname(self):
@@ -204,20 +218,17 @@ class MarkDecorator(object):
 
 def get_unpacked_marks(obj):
     """
-    obtain the unpacked marks that are stored on a object
+    obtain the unpacked marks that are stored on an object
     """
-    mark_list = getattr(obj, 'pytestmark', [])
+    mark_list = getattr(obj, "pytestmark", [])
 
     if not isinstance(mark_list, list):
         mark_list = [mark_list]
-    return [
-        getattr(mark, 'mark', mark)  # unpack MarkDecorator
-        for mark in mark_list
-    ]
+    return [getattr(mark, "mark", mark) for mark in mark_list]  # unpack MarkDecorator
 
 
 def store_mark(obj, mark):
-    """store a Mark on a object
+    """store a Mark on an object
     this is used to implement the Mark declarations/decorators correctly
     """
     assert isinstance(mark, Mark), mark
@@ -233,7 +244,7 @@ def store_legacy_markinfo(func, mark):
         raise TypeError("got {mark!r} instead of a Mark".format(mark=mark))
     holder = getattr(func, mark.name, None)
     if holder is None:
-        holder = MarkInfo(mark)
+        holder = MarkInfo.for_mark(mark)
         setattr(func, mark.name, holder)
     else:
         holder.add_mark(mark)
@@ -260,26 +271,34 @@ def _marked(func, mark):
     invoked more than once.
     """
     try:
-        func_mark = getattr(func, mark.name)
+        func_mark = getattr(func, getattr(mark, "combined", mark).name)
     except AttributeError:
         return False
-    return mark.args == func_mark.args and mark.kwargs == func_mark.kwargs
+    return any(mark == info.combined for info in func_mark)
 
 
+@attr.s
 class MarkInfo(object):
     """ Marking object created by :class:`MarkDecorator` instances. """
 
-    def __init__(self, mark):
-        assert isinstance(mark, Mark), repr(mark)
-        self.combined = mark
-        self._marks = [mark]
+    _marks = attr.ib()
+    combined = attr.ib(
+        repr=False,
+        default=attr.Factory(
+            lambda self: reduce(Mark.combined_with, self._marks), takes_self=True
+        ),
+    )
 
-    name = alias('combined.name')
-    args = alias('combined.args')
-    kwargs = alias('combined.kwargs')
+    name = alias("combined.name", warning=MARK_INFO_ATTRIBUTE)
+    args = alias("combined.args", warning=MARK_INFO_ATTRIBUTE)
+    kwargs = alias("combined.kwargs", warning=MARK_INFO_ATTRIBUTE)
+
+    @classmethod
+    def for_mark(cls, mark):
+        return cls([mark])
 
     def __repr__(self):
-        return "<MarkInfo {0!r}>".format(self.combined)
+        return "<MarkInfo {!r}>".format(self.combined)
 
     def add_mark(self, mark):
         """ add a MarkInfo with the given args and kwargs. """
@@ -288,7 +307,7 @@ class MarkInfo(object):
 
     def __iter__(self):
         """ yield MarkInfo objects each relating to a marking-call. """
-        return map(MarkInfo, self._marks)
+        return map(MarkInfo.for_mark, self._marks)
 
 
 class MarkGenerator(object):
@@ -331,6 +350,7 @@ MARK_GEN = MarkGenerator()
 
 
 class NodeKeywords(MappingMixin):
+
     def __init__(self, node):
         self.node = node
         self.parent = node.parent
@@ -364,4 +384,34 @@ class NodeKeywords(MappingMixin):
         return len(self._seen())
 
     def __repr__(self):
-        return "<NodeKeywords for node %s>" % (self.node, )
+        return "<NodeKeywords for node %s>" % (self.node,)
+
+
+@attr.s(cmp=False, hash=False)
+class NodeMarkers(object):
+    """
+    internal strucutre for storing marks belongong to a node
+
+    ..warning::
+
+        unstable api
+
+    """
+    own_markers = attr.ib(default=attr.Factory(list))
+
+    def update(self, add_markers):
+        """update the own markers
+        """
+        self.own_markers.extend(add_markers)
+
+    def find(self, name):
+        """
+        find markers in own nodes or parent nodes
+        needs a better place
+        """
+        for mark in self.own_markers:
+            if mark.name == name:
+                yield mark
+
+    def __iter__(self):
+        return iter(self.own_markers)
