@@ -16,8 +16,13 @@ from more_itertools import collapse
 
 import pytest
 from _pytest import nodes
-from _pytest.main import EXIT_OK, EXIT_TESTSFAILED, EXIT_INTERRUPTED, \
-    EXIT_USAGEERROR, EXIT_NOTESTSCOLLECTED
+from _pytest.main import (
+    EXIT_OK,
+    EXIT_TESTSFAILED,
+    EXIT_INTERRUPTED,
+    EXIT_USAGEERROR,
+    EXIT_NOTESTSCOLLECTED,
+)
 
 
 import argparse
@@ -30,93 +35,140 @@ class MoreQuietAction(argparse.Action):
 
     used to unify verbosity handling
     """
-    def __init__(self,
-                 option_strings,
-                 dest,
-                 default=None,
-                 required=False,
-                 help=None):
+
+    def __init__(self, option_strings, dest, default=None, required=False, help=None):
         super(MoreQuietAction, self).__init__(
             option_strings=option_strings,
             dest=dest,
             nargs=0,
             default=default,
             required=required,
-            help=help)
+            help=help,
+        )
 
     def __call__(self, parser, namespace, values, option_string=None):
         new_count = getattr(namespace, self.dest, 0) - 1
         setattr(namespace, self.dest, new_count)
         # todo Deprecate config.quiet
-        namespace.quiet = getattr(namespace, 'quiet', 0) + 1
+        namespace.quiet = getattr(namespace, "quiet", 0) + 1
 
 
 def pytest_addoption(parser):
     group = parser.getgroup("terminal reporting", "reporting", after="general")
-    group._addoption('-v', '--verbose', action="count", default=0,
-                     dest="verbose", help="increase verbosity."),
-    group._addoption('-q', '--quiet', action=MoreQuietAction, default=0,
-                     dest="verbose", help="decrease verbosity."),
-    group._addoption("--verbosity", dest='verbose', type=int, default=0,
-                     help="set verbosity")
-    group._addoption('-r',
-                     action="store", dest="reportchars", default='', metavar="chars",
-                     help="show extra test summary info as specified by chars (f)ailed, "
-                     "(E)error, (s)skipped, (x)failed, (X)passed, "
-                     "(p)passed, (P)passed with output, (a)all except pP. "
-                     "Warnings are displayed at all times except when "
-                     "--disable-warnings is set")
-    group._addoption('--disable-warnings', '--disable-pytest-warnings', default=False,
-                     dest='disable_warnings', action='store_true',
-                     help='disable warnings summary')
-    group._addoption('-l', '--showlocals',
-                     action="store_true", dest="showlocals", default=False,
-                     help="show locals in tracebacks (disabled by default).")
-    group._addoption('--tb', metavar="style",
-                     action="store", dest="tbstyle", default='auto',
-                     choices=['auto', 'long', 'short', 'no', 'line', 'native'],
-                     help="traceback print mode (auto/long/short/line/native/no).")
-    group._addoption('--show-capture',
-                     action="store", dest="showcapture",
-                     choices=['no', 'stdout', 'stderr', 'log', 'all'], default='all',
-                     help="Controls how captured stdout/stderr/log is shown on failed tests. "
-                          "Default is 'all'.")
-    group._addoption('--fulltrace', '--full-trace',
-                     action="store_true", default=False,
-                     help="don't cut any tracebacks (default is to cut).")
-    group._addoption('--color', metavar="color",
-                     action="store", dest="color", default='auto',
-                     choices=['yes', 'no', 'auto'],
-                     help="color terminal output (yes/no/auto).")
+    group._addoption(
+        "-v",
+        "--verbose",
+        action="count",
+        default=0,
+        dest="verbose",
+        help="increase verbosity.",
+    ),
+    group._addoption(
+        "-q",
+        "--quiet",
+        action=MoreQuietAction,
+        default=0,
+        dest="verbose",
+        help="decrease verbosity.",
+    ),
+    group._addoption(
+        "--verbosity", dest="verbose", type=int, default=0, help="set verbosity"
+    )
+    group._addoption(
+        "-r",
+        action="store",
+        dest="reportchars",
+        default="",
+        metavar="chars",
+        help="show extra test summary info as specified by chars (f)ailed, "
+        "(E)error, (s)skipped, (x)failed, (X)passed, "
+        "(p)passed, (P)passed with output, (a)all except pP. "
+        "Warnings are displayed at all times except when "
+        "--disable-warnings is set",
+    )
+    group._addoption(
+        "--disable-warnings",
+        "--disable-pytest-warnings",
+        default=False,
+        dest="disable_warnings",
+        action="store_true",
+        help="disable warnings summary",
+    )
+    group._addoption(
+        "-l",
+        "--showlocals",
+        action="store_true",
+        dest="showlocals",
+        default=False,
+        help="show locals in tracebacks (disabled by default).",
+    )
+    group._addoption(
+        "--tb",
+        metavar="style",
+        action="store",
+        dest="tbstyle",
+        default="auto",
+        choices=["auto", "long", "short", "no", "line", "native"],
+        help="traceback print mode (auto/long/short/line/native/no).",
+    )
+    group._addoption(
+        "--show-capture",
+        action="store",
+        dest="showcapture",
+        choices=["no", "stdout", "stderr", "log", "all"],
+        default="all",
+        help="Controls how captured stdout/stderr/log is shown on failed tests. "
+        "Default is 'all'.",
+    )
+    group._addoption(
+        "--fulltrace",
+        "--full-trace",
+        action="store_true",
+        default=False,
+        help="don't cut any tracebacks (default is to cut).",
+    )
+    group._addoption(
+        "--color",
+        metavar="color",
+        action="store",
+        dest="color",
+        default="auto",
+        choices=["yes", "no", "auto"],
+        help="color terminal output (yes/no/auto).",
+    )
 
-    parser.addini("console_output_style",
-                  help="console output: classic or with additional progress information (classic|progress).",
-                  default='progress')
+    parser.addini(
+        "console_output_style",
+        help="console output: classic or with additional progress information (classic|progress).",
+        default="progress",
+    )
 
 
 def pytest_configure(config):
     reporter = TerminalReporter(config, sys.stdout)
-    config.pluginmanager.register(reporter, 'terminalreporter')
+    config.pluginmanager.register(reporter, "terminalreporter")
     if config.option.debug or config.option.traceconfig:
+
         def mywriter(tags, args):
             msg = " ".join(map(str, args))
             reporter.write_line("[traceconfig] " + msg)
+
         config.trace.root.setprocessor("pytest:config", mywriter)
 
 
 def getreportopt(config):
     reportopts = ""
     reportchars = config.option.reportchars
-    if not config.option.disable_warnings and 'w' not in reportchars:
-        reportchars += 'w'
-    elif config.option.disable_warnings and 'w' in reportchars:
-        reportchars = reportchars.replace('w', '')
+    if not config.option.disable_warnings and "w" not in reportchars:
+        reportchars += "w"
+    elif config.option.disable_warnings and "w" in reportchars:
+        reportchars = reportchars.replace("w", "")
     if reportchars:
         for char in reportchars:
-            if char not in reportopts and char != 'a':
+            if char not in reportopts and char != "a":
                 reportopts += char
-            elif char == 'a':
-                reportopts = 'fEsxXw'
+            elif char == "a":
+                reportopts = "fEsxXw"
     return reportopts
 
 
@@ -161,15 +213,17 @@ class WarningReport(object):
             if isinstance(self.fslocation, tuple) and len(self.fslocation) >= 2:
                 filename, linenum = self.fslocation[:2]
                 relpath = py.path.local(filename).relto(config.invocation_dir)
-                return '%s:%s' % (relpath, linenum)
+                return "%s:%s" % (relpath, linenum)
             else:
                 return str(self.fslocation)
         return None
 
 
 class TerminalReporter(object):
+
     def __init__(self, config, file=None):
         import _pytest.config
+
         self.config = config
         self.verbosity = self.config.option.verbose
         self.showheader = self.verbosity >= 0
@@ -196,15 +250,15 @@ class TerminalReporter(object):
     def _determine_show_progress_info(self):
         """Return True if we should display progress information based on the current config"""
         # do not show progress if we are not capturing output (#3038)
-        if self.config.getoption('capture') == 'no':
+        if self.config.getoption("capture") == "no":
             return False
         # do not show progress if we are showing fixture setup/teardown
-        if self.config.getoption('setupshow'):
+        if self.config.getoption("setupshow"):
             return False
-        return self.config.getini('console_output_style') == 'progress'
+        return self.config.getini("console_output_style") == "progress"
 
     def hasopt(self, char):
-        char = {'xfailed': 'x', 'skipped': 's'}.get(char, char)
+        char = {"xfailed": "x", "skipped": "s"}.get(char, char)
         return char in self.reportchars
 
     def write_fspath_result(self, nodeid, res):
@@ -250,12 +304,12 @@ class TerminalReporter(object):
 
         The rest of the keyword arguments are markup instructions.
         """
-        erase = markup.pop('erase', False)
+        erase = markup.pop("erase", False)
         if erase:
             fill_count = self._tw.fullwidth - len(line) - 1
-            fill = ' ' * fill_count
+            fill = " " * fill_count
         else:
-            fill = ''
+            fill = ""
         line = str(line)
         self._tw.write("\r" + line + fill, **markup)
 
@@ -276,8 +330,9 @@ class TerminalReporter(object):
 
     def pytest_logwarning(self, code, fslocation, message, nodeid):
         warnings = self.stats.setdefault("warnings", [])
-        warning = WarningReport(code=code, fslocation=fslocation,
-                                message=message, nodeid=nodeid)
+        warning = WarningReport(
+            code=code, fslocation=fslocation, message=message, nodeid=nodeid
+        )
         warnings.append(warning)
 
     def pytest_plugin_registered(self, plugin):
@@ -289,7 +344,7 @@ class TerminalReporter(object):
             self.write_line(msg)
 
     def pytest_deselected(self, items):
-        self.stats.setdefault('deselected', []).extend(items)
+        self.stats.setdefault("deselected", []).extend(items)
 
     def pytest_runtest_logstart(self, nodeid, location):
         # ensure that the path is printed before the
@@ -314,7 +369,7 @@ class TerminalReporter(object):
         if not letter and not word:
             # probably passed setup/teardown
             return
-        running_xdist = hasattr(rep, 'node')
+        running_xdist = hasattr(rep, "node")
         if self.verbosity <= 0:
             if not running_xdist and self.showfspath:
                 self.write_fspath_result(rep.nodeid, letter)
@@ -324,11 +379,11 @@ class TerminalReporter(object):
             self._progress_nodeids_reported.add(rep.nodeid)
             if markup is None:
                 if rep.passed:
-                    markup = {'green': True}
+                    markup = {"green": True}
                 elif rep.failed:
-                    markup = {'red': True}
+                    markup = {"red": True}
                 elif rep.skipped:
-                    markup = {'yellow': True}
+                    markup = {"yellow": True}
                 else:
                     markup = {}
             line = self._locationline(rep.nodeid, *rep.location)
@@ -340,9 +395,11 @@ class TerminalReporter(object):
                 self.ensure_newline()
                 self._tw.write("[%s]" % rep.node.gateway.id)
                 if self._show_progress_info:
-                    self._tw.write(self._get_progress_information_message() + " ", cyan=True)
+                    self._tw.write(
+                        self._get_progress_information_message() + " ", cyan=True
+                    )
                 else:
-                    self._tw.write(' ')
+                    self._tw.write(" ")
                 self._tw.write(word, **markup)
                 self._tw.write(" " + line)
                 self.currentfspath = -2
@@ -350,29 +407,33 @@ class TerminalReporter(object):
     def pytest_runtest_logfinish(self, nodeid):
         if self.verbosity <= 0 and self._show_progress_info:
             self._progress_nodeids_reported.add(nodeid)
-            last_item = len(self._progress_nodeids_reported) == self._session.testscollected
+            last_item = len(
+                self._progress_nodeids_reported
+            ) == self._session.testscollected
             if last_item:
                 self._write_progress_information_filling_space()
             else:
                 past_edge = self._tw.chars_on_current_line + self._PROGRESS_LENGTH + 1 >= self._screen_width
                 if past_edge:
                     msg = self._get_progress_information_message()
-                    self._tw.write(msg + '\n', cyan=True)
+                    self._tw.write(msg + "\n", cyan=True)
 
-    _PROGRESS_LENGTH = len(' [100%]')
+    _PROGRESS_LENGTH = len(" [100%]")
 
     def _get_progress_information_message(self):
-        if self.config.getoption('capture') == 'no':
-            return ''
+        if self.config.getoption("capture") == "no":
+            return ""
         collected = self._session.testscollected
         if collected:
             progress = len(self._progress_nodeids_reported) * 100 // collected
-            return ' [{:3d}%]'.format(progress)
-        return ' [100%]'
+            return " [{:3d}%]".format(progress)
+        return " [100%]"
 
     def _write_progress_information_filling_space(self):
         msg = self._get_progress_information_message()
-        fill = ' ' * (self._tw.fullwidth - self._tw.chars_on_current_line - len(msg) - 1)
+        fill = " " * (
+            self._tw.fullwidth - self._tw.chars_on_current_line - len(msg) - 1
+        )
         self.write(fill + msg, cyan=True)
 
     def pytest_collection(self):
@@ -394,14 +455,16 @@ class TerminalReporter(object):
         if self.config.option.verbose < 0:
             return
 
-        errors = len(self.stats.get('error', []))
-        skipped = len(self.stats.get('skipped', []))
-        deselected = len(self.stats.get('deselected', []))
+        errors = len(self.stats.get("error", []))
+        skipped = len(self.stats.get("skipped", []))
+        deselected = len(self.stats.get("deselected", []))
         if final:
             line = "collected "
         else:
             line = "collecting "
-        line += str(self._numcollected) + " item" + ('' if self._numcollected == 1 else 's')
+        line += str(self._numcollected) + " item" + (
+            "" if self._numcollected == 1 else "s"
+        )
         if errors:
             line += " / %d errors" % errors
         if deselected:
@@ -411,7 +474,7 @@ class TerminalReporter(object):
         if self.isatty:
             self.rewrite(line, bold=True, erase=True)
             if final:
-                self.write('\n')
+                self.write("\n")
         else:
             self.write_line(line)
 
@@ -428,17 +491,22 @@ class TerminalReporter(object):
         self.write_sep("=", "test session starts", bold=True)
         verinfo = platform.python_version()
         msg = "platform %s -- Python %s" % (sys.platform, verinfo)
-        if hasattr(sys, 'pypy_version_info'):
+        if hasattr(sys, "pypy_version_info"):
             verinfo = ".".join(map(str, sys.pypy_version_info[:3]))
             msg += "[pypy-%s-%s]" % (verinfo, sys.pypy_version_info[3])
         msg += ", pytest-%s, py-%s, pluggy-%s" % (
-               pytest.__version__, py.__version__, pluggy.__version__)
-        if self.verbosity > 0 or self.config.option.debug or \
-           getattr(self.config.option, 'pastebin', None):
+            pytest.__version__, py.__version__, pluggy.__version__
+        )
+        if (
+            self.verbosity > 0
+            or self.config.option.debug
+            or getattr(self.config.option, "pastebin", None)
+        ):
             msg += " -- " + str(sys.executable)
         self.write_line(msg)
         lines = self.config.hook.pytest_report_header(
-            config=self.config, startdir=self.startdir)
+            config=self.config, startdir=self.startdir
+        )
         self._write_report_lines_from_hooks(lines)
 
     def _write_report_lines_from_hooks(self, lines):
@@ -455,21 +523,21 @@ class TerminalReporter(object):
         plugininfo = config.pluginmanager.list_plugin_distinfo()
         if plugininfo:
 
-            lines.append(
-                "plugins: %s" % ", ".join(_plugin_nameversions(plugininfo)))
+            lines.append("plugins: %s" % ", ".join(_plugin_nameversions(plugininfo)))
         return lines
 
     def pytest_collection_finish(self, session):
         if self.config.option.collectonly:
             self._printcollecteditems(session.items)
-            if self.stats.get('failed'):
+            if self.stats.get("failed"):
                 self._tw.sep("!", "collection failures")
-                for rep in self.stats.get('failed'):
+                for rep in self.stats.get("failed"):
                     rep.toterminal(self._tw)
                 return 1
             return 0
         lines = self.config.hook.pytest_report_collectionfinish(
-            config=self.config, startdir=self.startdir, items=session.items)
+            config=self.config, startdir=self.startdir, items=session.items
+        )
         self._write_report_lines_from_hooks(lines)
 
     def _printcollecteditems(self, items):
@@ -480,7 +548,7 @@ class TerminalReporter(object):
             if self.config.option.verbose < -1:
                 counts = {}
                 for item in items:
-                    name = item.nodeid.split('::', 1)[0]
+                    name = item.nodeid.split("::", 1)[0]
                     counts[name] = counts.get(name, 0) + 1
                 for name, count in sorted(counts.items()):
                     self._tw.line("%s: %d" % (name, count))
@@ -511,11 +579,16 @@ class TerminalReporter(object):
         outcome.get_result()
         self._tw.line("")
         summary_exit_codes = (
-            EXIT_OK, EXIT_TESTSFAILED, EXIT_INTERRUPTED, EXIT_USAGEERROR,
-            EXIT_NOTESTSCOLLECTED)
+            EXIT_OK,
+            EXIT_TESTSFAILED,
+            EXIT_INTERRUPTED,
+            EXIT_USAGEERROR,
+            EXIT_NOTESTSCOLLECTED,
+        )
         if exitstatus in summary_exit_codes:
-            self.config.hook.pytest_terminal_summary(terminalreporter=self,
-                                                     exitstatus=exitstatus)
+            self.config.hook.pytest_terminal_summary(
+                terminalreporter=self, exitstatus=exitstatus
+            )
         if exitstatus == EXIT_INTERRUPTED:
             self._report_keyboardinterrupt()
             del self._keyboardinterrupt_memo
@@ -533,7 +606,7 @@ class TerminalReporter(object):
         self._keyboardinterrupt_memo = excinfo.getrepr(funcargs=True)
 
     def pytest_unconfigure(self):
-        if hasattr(self, '_keyboardinterrupt_memo'):
+        if hasattr(self, "_keyboardinterrupt_memo"):
             self._report_keyboardinterrupt()
 
     def _report_keyboardinterrupt(self):
@@ -544,18 +617,23 @@ class TerminalReporter(object):
             if self.config.option.fulltrace:
                 excrepr.toterminal(self._tw)
             else:
-                self._tw.line("to show a full traceback on KeyboardInterrupt use --fulltrace", yellow=True)
+                self._tw.line(
+                    "to show a full traceback on KeyboardInterrupt use --fulltrace",
+                    yellow=True,
+                )
                 excrepr.reprcrash.toterminal(self._tw)
 
     def _locationline(self, nodeid, fspath, lineno, domain):
+
         def mkrel(nodeid):
             line = self.config.cwd_relative_nodeid(nodeid)
             if domain and line.endswith(domain):
                 line = line[:-len(domain)]
                 values = domain.split("[")
-                values[0] = values[0].replace('.', '::')  # don't replace '.' in params
+                values[0] = values[0].replace(".", "::")  # don't replace '.' in params
                 line += "[".join(values)
             return line
+
         # collect_fspath comes from testid which has a "/"-normalized path
 
         if fspath:
@@ -567,7 +645,7 @@ class TerminalReporter(object):
         return res + " "
 
     def _getfailureheadline(self, rep):
-        if hasattr(rep, 'location'):
+        if hasattr(rep, "location"):
             fspath, lineno, domain = rep.location
             return domain
         else:
@@ -588,7 +666,7 @@ class TerminalReporter(object):
     def getreports(self, name):
         values = []
         for x in self.stats.get(name, []):
-            if not hasattr(x, '_pdbshown'):
+            if not hasattr(x, "_pdbshown"):
                 values.append(x)
         return values
 
@@ -598,22 +676,24 @@ class TerminalReporter(object):
             if not all_warnings:
                 return
 
-            grouped = itertools.groupby(all_warnings, key=lambda wr: wr.get_location(self.config))
+            grouped = itertools.groupby(
+                all_warnings, key=lambda wr: wr.get_location(self.config)
+            )
 
             self.write_sep("=", "warnings summary", yellow=True, bold=False)
             for location, warning_records in grouped:
-                self._tw.line(str(location) or '<undetermined location>')
+                self._tw.line(str(location) or "<undetermined location>")
                 for w in warning_records:
                     lines = w.message.splitlines()
-                    indented = '\n'.join('  ' + x for x in lines)
+                    indented = "\n".join("  " + x for x in lines)
                     self._tw.line(indented)
                 self._tw.line()
-            self._tw.line('-- Docs: http://doc.pytest.org/en/latest/warnings.html')
+            self._tw.line("-- Docs: http://doc.pytest.org/en/latest/warnings.html")
 
     def summary_passes(self):
         if self.config.option.tbstyle != "no":
             if self.hasopt("P"):
-                reports = self.getreports('passed')
+                reports = self.getreports("passed")
                 if not reports:
                     return
                 self.write_sep("=", "PASSES")
@@ -624,15 +704,15 @@ class TerminalReporter(object):
 
     def print_teardown_sections(self, rep):
         for secname, content in rep.sections:
-            if 'teardown' in secname:
-                self._tw.sep('-', secname)
+            if "teardown" in secname:
+                self._tw.sep("-", secname)
                 if content[-1:] == "\n":
                     content = content[:-1]
                 self._tw.line(content)
 
     def summary_failures(self):
         if self.config.option.tbstyle != "no":
-            reports = self.getreports('failed')
+            reports = self.getreports("failed")
             if not reports:
                 return
             self.write_sep("=", "FAILURES")
@@ -642,22 +722,22 @@ class TerminalReporter(object):
                     self.write_line(line)
                 else:
                     msg = self._getfailureheadline(rep)
-                    markup = {'red': True, 'bold': True}
+                    markup = {"red": True, "bold": True}
                     self.write_sep("_", msg, **markup)
                     self._outrep_summary(rep)
-                    for report in self.getreports(''):
-                        if report.nodeid == rep.nodeid and report.when == 'teardown':
+                    for report in self.getreports(""):
+                        if report.nodeid == rep.nodeid and report.when == "teardown":
                             self.print_teardown_sections(report)
 
     def summary_errors(self):
         if self.config.option.tbstyle != "no":
-            reports = self.getreports('error')
+            reports = self.getreports("error")
             if not reports:
                 return
             self.write_sep("=", "ERRORS")
-            for rep in self.stats['error']:
+            for rep in self.stats["error"]:
                 msg = self._getfailureheadline(rep)
-                if not hasattr(rep, 'when'):
+                if not hasattr(rep, "when"):
                     # collect
                     msg = "ERROR collecting " + msg
                 elif rep.when == "setup":
@@ -670,10 +750,10 @@ class TerminalReporter(object):
     def _outrep_summary(self, rep):
         rep.toterminal(self._tw)
         showcapture = self.config.option.showcapture
-        if showcapture == 'no':
+        if showcapture == "no":
             return
         for secname, content in rep.sections:
-            if showcapture != 'all' and showcapture not in secname:
+            if showcapture != "all" and showcapture not in secname:
                 continue
             self._tw.sep("-", secname)
             if content[-1:] == "\n":
@@ -684,7 +764,7 @@ class TerminalReporter(object):
         session_duration = time.time() - self._sessionstarttime
         (line, color) = build_summary_stats_line(self.stats)
         msg = "%s in %.2f seconds" % (line, session_duration)
-        markup = {color: True, 'bold': True}
+        markup = {color: True, "bold": True}
 
         if self.verbosity >= 0:
             self.write_sep("=", msg, **markup)
@@ -702,8 +782,9 @@ def repr_pythonversion(v=None):
 
 
 def build_summary_stats_line(stats):
-    keys = ("failed passed skipped deselected "
-            "xfailed xpassed warnings error").split()
+    keys = (
+        "failed passed skipped deselected " "xfailed xpassed warnings error"
+    ).split()
     unknown_key_seen = False
     for key in stats.keys():
         if key not in keys:
@@ -721,14 +802,14 @@ def build_summary_stats_line(stats):
     else:
         line = "no tests ran"
 
-    if 'failed' in stats or 'error' in stats:
-        color = 'red'
-    elif 'warnings' in stats or unknown_key_seen:
-        color = 'yellow'
-    elif 'passed' in stats:
-        color = 'green'
+    if "failed" in stats or "error" in stats:
+        color = "red"
+    elif "warnings" in stats or unknown_key_seen:
+        color = "yellow"
+    elif "passed" in stats:
+        color = "green"
     else:
-        color = 'yellow'
+        color = "yellow"
 
     return (line, color)
 
@@ -737,7 +818,7 @@ def _plugin_nameversions(plugininfo):
     values = []
     for plugin, dist in plugininfo:
         # gets us name and version!
-        name = '{dist.project_name}-{dist.version}'.format(dist=dist)
+        name = "{dist.project_name}-{dist.version}".format(dist=dist)
         # questionable convenience, but it keeps things short
         if name.startswith("pytest-"):
             name = name[7:]
